==> pydantic2_schemaorg-0.1.0-py3-none-any.whl: pydantic2_schemaorg/ReceiveAction.py <==
from __future__ import annotations

from typing import TYPE_CHECKING

from pydantic.v1 import Field

from pydantic2_schemaorg.TransferAction import TransferAction


class ReceiveAction(TransferAction):
    """The act of physically/electronically taking delivery of an object that has been transferred"
     "from an origin to a destination. Reciprocal of SendAction. Related actions: * [[SendAction]]:"
     "The reciprocal of ReceiveAction. * [[TakeAction]]: Unlike TakeAction, ReceiveAction"
     "does not imply that the ownership has been transferred (e.g. I can receive a package,"
     "but it does not mean the package is now mine).

    See: https://schema.org/ReceiveAction
    Model depth: 4
    """

    type_: str = Field(default="ReceiveAction", alias="@type", const=True)
    sender: None | (
        list[Audience | Organization | Person | str]
        | Audience
        | Organization
        | Person
        | str
    ) = Field(
        default=None,
        description="A sub property of participant. The participant who is at the sending end of the action.",
    )
    deliveryMethod: None | (list[DeliveryMethod | str] | DeliveryMethod | str) = Field(
        default=None,
        description="A sub property of instrument. The method of delivery.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod

==> pydantic2_schemaorg-0.1.1-py3-none-any.whl: pydantic2_schemaorg/ReceiveAction.py <==
from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class ReceiveAction(TransferAction):
    """The act of physically/electronically taking delivery of an object that has been transferred"
     "from an origin to a destination. Reciprocal of SendAction. Related actions: * [[SendAction]]:"
     "The reciprocal of ReceiveAction. * [[TakeAction]]: Unlike TakeAction, ReceiveAction"
     "does not imply that the ownership has been transferred (e.g. I can receive a package,"
     "but it does not mean the package is now mine).

    See: https://schema.org/ReceiveAction
    Model depth: 4
    """

    type_: str = Field(default="ReceiveAction", alias="@type", const=True)
    sender: Optional[
        Union[
            List[Union["Audience", "Organization", "Person", str]],
            "Audience",
            "Organization",
            "Person",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the sending end of the action.",
    )
    deliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="A sub property of instrument. The method of delivery.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod
